@@ -2,6 +2,4 @@ from .default import DefaultClient
 from .herd import HerdClient
 from .sharded import ShardClient
 
-__all__ = ["DefaultClient",
-           "ShardClient",
-           "HerdClient"]
+__all__ = ["DefaultClient", "ShardClient", "HerdClient"]
