@@ -6,7 +6,6 @@ from collections import OrderedDict
 from django.conf import settings
 from django.core.cache.backends.base import DEFAULT_TIMEOUT, get_key_func
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.encoding import smart_text
 from django.utils.module_loading import import_string
 from redis.exceptions import ConnectionError, ResponseError, TimeoutError
 
@@ -17,11 +16,11 @@ from ..util import CacheKey
 _main_exceptions = (TimeoutError, ResponseError, ConnectionError, socket.timeout)
 
 
-special_re = re.compile('([*?[])')
+special_re = re.compile("([*?[])")
 
 
 def glob_escape(s):
-    return special_re.sub(r'[\1]', s)
+    return special_re.sub(r"[\1]", s)
 
 
 class DefaultClient:
@@ -31,7 +30,8 @@ class DefaultClient:
         self._params = params
 
         self.reverse_key = get_key_func(
-            params.get("REVERSE_KEY_FUNCTION") or "django_redis.util.default_reverse_key"
+            params.get("REVERSE_KEY_FUNCTION")
+            or "django_redis.util.default_reverse_key"
         )
 
         if not self._server:
@@ -42,12 +42,16 @@ class DefaultClient:
 
         self._clients = [None] * len(self._server)
         self._options = params.get("OPTIONS", {})
-        self._slave_read_only = self._options.get('SLAVE_READ_ONLY', True)
+        self._slave_read_only = self._options.get("SLAVE_READ_ONLY", True)
 
-        serializer_path = self._options.get("SERIALIZER", "django_redis.serializers.pickle.PickleSerializer")
+        serializer_path = self._options.get(
+            "SERIALIZER", "django_redis.serializers.pickle.PickleSerializer"
+        )
         serializer_cls = import_string(serializer_path)
 
-        compressor_path = self._options.get("COMPRESSOR", "django_redis.compressors.identity.IdentityCompressor")
+        compressor_path = self._options.get(
+            "COMPRESSOR", "django_redis.compressors.identity.IdentityCompressor"
+        )
         compressor_cls = import_string(compressor_path)
 
         self._serializer = serializer_cls(options=self._options)
@@ -102,10 +106,21 @@ class DefaultClient:
         """
         return self.connection_factory.connect(self._server[index])
 
-    def set(self, key, value, timeout=DEFAULT_TIMEOUT, version=None, client=None, nx=False, xx=False):
+    def set(
+        self,
+        key,
+        value,
+        timeout=DEFAULT_TIMEOUT,
+        version=None,
+        client=None,
+        nx=False,
+        xx=False,
+    ):
         """
         Persist a value to the cache, and set an optional expiration time.
-        Also supports optional nx parameter. If set to True - will use redis setnx instead of set.
+
+        Also supports optional nx parameter. If set to True - will use redis
+        setnx instead of set.
         """
         nkey = self.make_key(key, version=version)
         nvalue = self.encode(value)
@@ -117,8 +132,10 @@ class DefaultClient:
         tried = []
         while True:
             try:
-                if not client:
-                    client, index = self.get_client(write=True, tried=tried, show_index=True)
+                if client is None:
+                    client, index = self.get_client(
+                        write=True, tried=tried, show_index=True
+                    )
 
                 if timeout is not None:
                     # Convert to milliseconds
@@ -138,11 +155,15 @@ class DefaultClient:
 
                 return bool(client.set(nkey, nvalue, nx=nx, px=timeout, xx=xx))
             except _main_exceptions as e:
-                if not original_client and not self._slave_read_only and len(tried) < len(self._server):
+                if (
+                    not original_client
+                    and not self._slave_read_only
+                    and len(tried) < len(self._server)
+                ):
                     tried.append(index)
                     client = None
                     continue
-                raise ConnectionInterrupted(connection=client, parent=e)
+                raise ConnectionInterrupted(connection=client) from e
 
     def incr_version(self, key, delta=1, version=None, client=None):
         """
@@ -162,7 +183,7 @@ class DefaultClient:
         try:
             ttl = client.ttl(old_key)
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
         if value is None:
             raise ValueError("Key '%s' not found" % key)
@@ -198,7 +219,7 @@ class DefaultClient:
         try:
             value = client.get(key)
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
         if value is None:
             return default
@@ -223,14 +244,27 @@ class DefaultClient:
         if client.exists(key):
             client.expire(key, timeout)
 
-    def lock(self, key, version=None, timeout=None, sleep=0.1,
-             blocking_timeout=None, client=None):
+    def lock(
+        self,
+        key,
+        version=None,
+        timeout=None,
+        sleep=0.1,
+        blocking_timeout=None,
+        client=None,
+        thread_local=True,
+    ):
         if client is None:
             client = self.get_client(write=True)
 
         key = self.make_key(key, version=version)
-        return client.lock(key, timeout=timeout, sleep=sleep,
-                           blocking_timeout=blocking_timeout)
+        return client.lock(
+            key,
+            timeout=timeout,
+            sleep=sleep,
+            blocking_timeout=blocking_timeout,
+            thread_local=thread_local,
+        )
 
     def delete(self, key, version=None, prefix=None, client=None):
         """
@@ -240,12 +274,13 @@ class DefaultClient:
             client = self.get_client(write=True)
 
         try:
-            return client.delete(self.make_key(key, version=version,
-                                               prefix=prefix))
+            return client.delete(self.make_key(key, version=version, prefix=prefix))
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
-    def delete_pattern(self, pattern, version=None, prefix=None, client=None, itersize=None):
+    def delete_pattern(
+        self, pattern, version=None, prefix=None, client=None, itersize=None
+    ):
         """
         Remove all keys matching pattern.
         """
@@ -255,9 +290,9 @@ class DefaultClient:
 
         pattern = self.make_pattern(pattern, version=version, prefix=prefix)
 
-        kwargs = {'match': pattern, }
+        kwargs = {"match": pattern}
         if itersize:
-            kwargs['count'] = itersize
+            kwargs["count"] = itersize
 
         try:
             count = 0
@@ -266,7 +301,7 @@ class DefaultClient:
                 count += 1
             return count
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
     def delete_many(self, keys, version=None, client=None):
         """
@@ -284,7 +319,7 @@ class DefaultClient:
         try:
             return client.delete(*keys)
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
     def clear(self, client=None):
         """
@@ -297,7 +332,7 @@ class DefaultClient:
         try:
             client.flushdb()
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
     def decode(self, value):
         """
@@ -339,14 +374,12 @@ class DefaultClient:
 
         recovered_data = OrderedDict()
 
-        map_keys = OrderedDict(
-            (self.make_key(k, version=version), k) for k in keys
-        )
+        map_keys = OrderedDict((self.make_key(k, version=version), k) for k in keys)
 
         try:
             results = client.mget(*map_keys)
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
         for key, value in zip(map_keys, results):
             if value is None:
@@ -371,7 +404,7 @@ class DefaultClient:
                 self.set(key, value, timeout, version=version, client=pipeline)
             pipeline.execute()
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
     def _incr(self, key, delta=1, version=None, client=None, ignore_key_check=False):
         if client is None:
@@ -412,10 +445,9 @@ class DefaultClient:
                 if timeout == -2:
                     raise ValueError("Key '%s' not found" % key)
                 value = self.get(key, version=version, client=client) + delta
-                self.set(key, value, version=version, timeout=timeout,
-                         client=client)
+                self.set(key, value, version=version, timeout=timeout, client=client)
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
         return value
 
@@ -425,15 +457,20 @@ class DefaultClient:
         ValueError exception. if ignore_key_check=True then the key will be
         created and set to the delta value by default.
         """
-        return self._incr(key=key, delta=delta, version=version, client=client, ignore_key_check=ignore_key_check)
+        return self._incr(
+            key=key,
+            delta=delta,
+            version=version,
+            client=client,
+            ignore_key_check=ignore_key_check,
+        )
 
     def decr(self, key, delta=1, version=None, client=None):
         """
         Decreace delta to value in the cache. If the key does not exist, raise a
         ValueError exception.
         """
-        return self._incr(key=key, delta=-delta, version=version,
-                          client=client)
+        return self._incr(key=key, delta=-delta, version=version, client=client)
 
     def ttl(self, key, version=None, client=None):
         """
@@ -471,7 +508,7 @@ class DefaultClient:
         try:
             return client.exists(key) == 1
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
     def iter_keys(self, search, itersize=None, client=None, version=None):
         """
@@ -484,8 +521,7 @@ class DefaultClient:
 
         pattern = self.make_pattern(search, version=version)
         for item in client.scan_iter(match=pattern, count=itersize):
-            item = smart_text(item)
-            yield self.reverse_key(item)
+            yield self.reverse_key(item.decode())
 
     def keys(self, search, version=None, client=None):
         """
@@ -500,10 +536,9 @@ class DefaultClient:
 
         pattern = self.make_pattern(search, version=version)
         try:
-            encoding_map = [smart_text(k) for k in client.keys(pattern)]
-            return [self.reverse_key(k) for k in encoding_map]
+            return [self.reverse_key(k.decode()) for k in client.keys(pattern)]
         except _main_exceptions as e:
-            raise ConnectionInterrupted(connection=client, parent=e)
+            raise ConnectionInterrupted(connection=client) from e
 
     def make_key(self, key, version=None, prefix=None):
         if isinstance(key, CacheKey):
@@ -543,9 +578,16 @@ class DefaultClient:
         Sets a new expiration for a key.
         """
 
+        if timeout is DEFAULT_TIMEOUT:
+            timeout = self._backend.default_timeout
+
         if client is None:
             client = self.get_client(write=True)
 
         key = self.make_key(key, version=version)
-
-        return client.expire(key, timeout)
+        if timeout is None:
+            return bool(client.persist(key))
+        else:
+            # Convert to milliseconds
+            timeout = int(timeout * 1000)
+            return bool(client.pexpire(key, timeout))
