@@ -2,7 +2,6 @@ import re
 from collections import OrderedDict
 
 from django.conf import settings
-from django.utils.encoding import smart_text
 from redis.exceptions import ConnectionError
 
 from ..exceptions import ConnectionInterrupted
@@ -12,7 +11,7 @@ from .default import DEFAULT_TIMEOUT, DefaultClient
 
 
 class ShardClient(DefaultClient):
-    _findhash = re.compile(r'.*\{(.*)\}.*', re.I)
+    _findhash = re.compile(r".*\{(.*)\}.*", re.I)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -49,16 +48,16 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super()\
-            .add(key=key, value=value, version=version, client=client, timeout=timeout)
+        return super().add(
+            key=key, value=value, version=version, client=client, timeout=timeout
+        )
 
     def get(self, key, default=None, version=None, client=None):
         if client is None:
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super()\
-            .get(key=key, default=default, version=version, client=client)
+        return super().get(key=key, default=default, version=version, client=client)
 
     def get_many(self, keys, version=None):
         if not keys:
@@ -79,7 +78,9 @@ class ShardClient(DefaultClient):
             recovered_data[map_keys[key]] = value
         return recovered_data
 
-    def set(self, key, value, timeout=DEFAULT_TIMEOUT, version=None, client=None, nx=False):
+    def set(
+        self, key, value, timeout=DEFAULT_TIMEOUT, version=None, client=None, nx=False
+    ):
         """
         Persist a value to the cache, and set an optional expiration time.
         """
@@ -87,9 +88,9 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super().set(key=key, value=value,
-                           timeout=timeout, version=version,
-                           client=client, nx=nx)
+        return super().set(
+            key=key, value=value, timeout=timeout, version=version, client=client, nx=nx
+        )
 
     def set_many(self, data, timeout=DEFAULT_TIMEOUT, version=None):
         """
@@ -114,8 +115,8 @@ class ShardClient(DefaultClient):
         key = self.make_key(key, version=version)
         try:
             return client.exists(key) == 1
-        except ConnectionError:
-            raise ConnectionInterrupted(connection=client)
+        except ConnectionError as e:
+            raise ConnectionInterrupted(connection=client) from e
 
     def delete(self, key, version=None, client=None):
         if client is None:
@@ -148,19 +149,32 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super().expire(key=key, timeout=timeout,
-                              version=version, client=client)
+        return super().expire(key=key, timeout=timeout, version=version, client=client)
 
-    def lock(self, key, version=None, timeout=None, sleep=0.1,
-             blocking_timeout=None, client=None):
+    def lock(
+        self,
+        key,
+        version=None,
+        timeout=None,
+        sleep=0.1,
+        blocking_timeout=None,
+        client=None,
+        thread_local=True,
+    ):
 
         if client is None:
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
         key = self.make_key(key, version=version)
-        return super().lock(key, timeout=timeout, sleep=sleep, client=client,
-                            blocking_timeout=blocking_timeout)
+        return super().lock(
+            key,
+            timeout=timeout,
+            sleep=sleep,
+            client=client,
+            blocking_timeout=blocking_timeout,
+            thread_local=thread_local,
+        )
 
     def delete_many(self, keys, version=None):
         """
@@ -185,8 +199,8 @@ class ShardClient(DefaultClient):
 
         try:
             ttl = client.ttl(old_key)
-        except ConnectionError:
-            raise ConnectionInterrupted(connection=client)
+        except ConnectionError as e:
+            raise ConnectionInterrupted(connection=client) from e
 
         if value is None:
             raise ValueError("Key '%s' not found" % key)
@@ -205,16 +219,14 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super()\
-            .incr(key=key, delta=delta, version=version, client=client)
+        return super().incr(key=key, delta=delta, version=version, client=client)
 
     def decr(self, key, delta=1, version=None, client=None):
         if client is None:
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super()\
-            .decr(key=key, delta=delta, version=version, client=client)
+        return super().decr(key=key, delta=delta, version=version, client=client)
 
     def iter_keys(self, key, version=None):
         raise NotImplementedError("iter_keys not supported on sharded client")
@@ -225,22 +237,23 @@ class ShardClient(DefaultClient):
         try:
             for server, connection in self._serverdict.items():
                 keys.extend(connection.keys(pattern))
-        except ConnectionError:
+        except ConnectionError as e:
             # FIXME: technically all clients should be passed as `connection`.
             client = self.get_server(pattern)
-            raise ConnectionInterrupted(connection=client)
+            raise ConnectionInterrupted(connection=client) from e
 
-        decoded_keys = (smart_text(k) for k in keys)
-        return [self.reverse_key(k) for k in decoded_keys]
+        return [self.reverse_key(k.decode()) for k in keys]
 
-    def delete_pattern(self, pattern, version=None, client=None, itersize=None, prefix=None):
+    def delete_pattern(
+        self, pattern, version=None, client=None, itersize=None, prefix=None
+    ):
         """
         Remove all keys matching pattern.
         """
         pattern = self.make_pattern(pattern, version=version, prefix=prefix)
-        kwargs = {'match': pattern}
+        kwargs = {"match": pattern}
         if itersize:
-            kwargs['count'] = itersize
+            kwargs["count"] = itersize
 
         keys = []
         for server, connection in self._serverdict.items():
@@ -263,5 +276,4 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super().touch(key=key, timeout=timeout,
-                             version=version, client=client)
+        return super().touch(key=key, timeout=timeout, version=version, client=client)
