@@ -1,9 +1,4 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, unicode_literals
-
-
-class BaseSerializer(object):
+class BaseSerializer:
     def __init__(self, options):
         pass
 
