@@ -1,20 +1,9 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, unicode_literals
+import pickle
 
 from django.core.exceptions import ImproperlyConfigured
 
 from .base import BaseSerializer
 
-# Import the fastest implementation of
-# pickle package. This should be removed
-# when python3 come the unique supported
-# python version
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
-
 
 class PickleSerializer(BaseSerializer):
     def __init__(self, options):
