@@ -1,12 +1,12 @@
 import base64
 import copy
 import datetime
+import threading
 import time
 import unittest
 from datetime import timedelta
 from unittest.mock import Mock, patch
 
-from django import VERSION
 from django.conf import settings
 from django.contrib.sessions.backends.cache import SessionStore as CacheSession
 from django.core.cache import DEFAULT_CACHE_ALIAS, cache, caches
@@ -32,75 +32,72 @@ def reverse_key(key):
 
 
 class DjangoRedisConnectionStrings(unittest.TestCase):
-    def setUp(self):
-        self.cf = pool.get_connection_factory(options={})
-        self.constring4 = "unix://tmp/foo.bar?db=1"
-        self.constring5 = "redis://localhost/2"
-        self.constring6 = "rediss://localhost:3333?db=2"
-
-    def test_new_connection_strings(self):
-        res1 = self.cf.make_connection_params(self.constring4)
-        res2 = self.cf.make_connection_params(self.constring5)
-        res3 = self.cf.make_connection_params(self.constring6)
-
-        self.assertEqual(res1["url"], self.constring4)
-        self.assertEqual(res2["url"], self.constring5)
-        self.assertEqual(res3["url"], self.constring6)
+    def test_connection_strings(self):
+        connection_strings = [
+            "unix://tmp/foo.bar?db=1",
+            "redis://localhost/2",
+            "rediss://localhost:3333?db=2",
+        ]
+        cf = pool.get_connection_factory(options={})
+        for connection_string in connection_strings:
+            with self.subTest(connection_string):
+                res = cf.make_connection_params(connection_string)
+                self.assertEqual(res["url"], connection_string)
 
 
 class DjangoRedisCacheTestEscapePrefix(unittest.TestCase):
     def setUp(self):
 
         caches_setting = copy.deepcopy(settings.CACHES)
-        caches_setting['default']['KEY_PREFIX'] = '*'
+        caches_setting["default"]["KEY_PREFIX"] = "*"
         cm = override_settings(CACHES=caches_setting)
         cm.enable()
         self.addCleanup(cm.disable)
 
-        self.cache = caches['default']
+        self.cache = caches["default"]
         try:
             self.cache.clear()
         except Exception:
             pass
-        self.other = caches['with_prefix']
+        self.other = caches["with_prefix"]
         try:
             self.other.clear()
         except Exception:
             pass
 
     def test_delete_pattern(self):
-        self.cache.set('a', '1')
-        self.other.set('b', '2')
-        self.cache.delete_pattern('*')
-        self.assertIs(self.cache.has_key('a'), False)
-        self.assertEqual(self.other.get('b'), '2')
+        self.cache.set("a", "1")
+        self.other.set("b", "2")
+        self.cache.delete_pattern("*")
+        self.assertIs(self.cache.has_key("a"), False)
+        self.assertEqual(self.other.get("b"), "2")
 
     def test_iter_keys(self):
         if isinstance(self.cache.client, ShardClient):
             self.skipTest("ShardClient doesn't support iter_keys")
 
-        self.cache.set('a', '1')
-        self.other.set('b', '2')
-        self.assertEqual(list(self.cache.iter_keys('*')), ['a'])
+        self.cache.set("a", "1")
+        self.other.set("b", "2")
+        self.assertEqual(list(self.cache.iter_keys("*")), ["a"])
 
     def test_keys(self):
-        self.cache.set('a', '1')
-        self.other.set('b', '2')
-        keys = self.cache.keys('*')
-        self.assertIn('a', keys)
-        self.assertNotIn('b', keys)
+        self.cache.set("a", "1")
+        self.other.set("b", "2")
+        keys = self.cache.keys("*")
+        self.assertIn("a", keys)
+        self.assertNotIn("b", keys)
 
 
 class DjangoRedisCacheTestCustomKeyFunction(unittest.TestCase):
     def setUp(self):
         caches_setting = copy.deepcopy(settings.CACHES)
-        caches_setting['default']['KEY_FUNCTION'] = 'test_backend.make_key'
-        caches_setting['default']['REVERSE_KEY_FUNCTION'] = 'test_backend.reverse_key'
+        caches_setting["default"]["KEY_FUNCTION"] = "test_backend.make_key"
+        caches_setting["default"]["REVERSE_KEY_FUNCTION"] = "test_backend.reverse_key"
         cm = override_settings(CACHES=caches_setting)
         cm.enable()
         self.addCleanup(cm.disable)
 
-        self.cache = caches['default']
+        self.cache = caches["default"]
         try:
             self.cache.clear()
         except Exception:
@@ -120,8 +117,9 @@ class DjangoRedisCacheTestCustomKeyFunction(unittest.TestCase):
         self.assertEqual(set(keys), {"foo-bb", "foo-bc"})
         # ensure our custom function was actually called
         self.assertEqual(
-            {k.decode() for k in self.cache.client.get_client(write=False).keys('*')},
-            {'#1#foo-bc', '#1#foo-bb'})
+            {k.decode() for k in self.cache.client.get_client(write=False).keys("*")},
+            {"#1#foo-bc", "#1#foo-bb"},
+        )
 
 
 class DjangoRedisCacheTests(unittest.TestCase):
@@ -172,9 +170,9 @@ class DjangoRedisCacheTests(unittest.TestCase):
         self.assertIsNone(res)
 
     def test_unicode_keys(self):
-        self.cache.set('ключ', 'value')
-        res = self.cache.get('ключ')
-        self.assertEqual(res, 'value')
+        self.cache.set("ключ", "value")
+        res = self.cache.get("ключ")
+        self.assertEqual(res, "value")
 
     def test_save_and_integer(self):
         self.cache.set("test_key", 2)
@@ -204,7 +202,9 @@ class DjangoRedisCacheTests(unittest.TestCase):
         self.assertEqual(res, "heló")
 
     def test_save_dict(self):
-        if isinstance(self.cache.client._serializer, (JSONSerializer, MSGPackSerializer)):
+        if isinstance(
+            self.cache.client._serializer, (JSONSerializer, MSGPackSerializer)
+        ):
             # JSONSerializer and MSGPackSerializer use the isoformat for
             # datetimes.
             now_dt = datetime.datetime.now().isoformat()
@@ -313,6 +313,39 @@ class DjangoRedisCacheTests(unittest.TestCase):
         res = self.cache.get_many(["a", "b", "c"])
         self.assertEqual(res, {"a": 1, "b": 2, "c": 3})
 
+    def test_set_call_empty_pipeline(self):
+        if isinstance(self.cache.client, ShardClient):
+            self.skipTest("ShardClient doesn't support get_client")
+
+        pipeline = self.cache.client.get_client(write=True).pipeline()
+        key = "key"
+        value = "value"
+
+        with patch.object(pipeline, "set") as mocked_set:
+            self.cache.set(
+                key, value, client=pipeline,
+            )
+
+        if isinstance(self.cache.client, herd.HerdClient):
+            default_timeout = self.cache.client._backend.default_timeout
+            herd_timeout = (default_timeout + herd.CACHE_HERD_TIMEOUT) * 1000
+            herd_pack_value = self.cache.client._pack(value, default_timeout,)
+            mocked_set.assert_called_once_with(
+                self.cache.client.make_key(key, version=None),
+                self.cache.client.encode(herd_pack_value),
+                nx=False,
+                px=herd_timeout,
+                xx=False,
+            )
+        else:
+            mocked_set.assert_called_once_with(
+                self.cache.client.make_key(key, version=None),
+                self.cache.client.encode(value),
+                nx=False,
+                px=self.cache.client._backend.default_timeout * 1000,
+                xx=False,
+            )
+
     def test_delete(self):
         self.cache.set_many({"a": 1, "b": 2, "c": 3})
         res = self.cache.delete("a")
@@ -387,15 +420,18 @@ class DjangoRedisCacheTests(unittest.TestCase):
 
         with self.assertRaises(ValueError):
             # key does not exist
-            self.cache.incr('numnum')
+            self.cache.incr("numnum")
 
     def test_incr_ignore_check(self):
         if isinstance(self.cache.client, ShardClient):
-            self.skipTest("ShardClient doesn't support argument ignore_key_check to incr")
+            self.skipTest(
+                "ShardClient doesn't support argument ignore_key_check to incr"
+            )
         if isinstance(self.cache.client, herd.HerdClient):
             self.skipTest("HerdClient doesn't support incr")
 
-        # key exists check will be skipped and the value will be incremented by '1' which is the default delta
+        # key exists check will be skipped and the value will be incremented by
+        # '1' which is the default delta
         self.cache.incr("num", ignore_key_check=True)
         res = self.cache.get("num")
         self.assertEqual(res, 1)
@@ -407,8 +443,8 @@ class DjangoRedisCacheTests(unittest.TestCase):
         self.assertEqual(res, 10)
         self.cache.delete("num")
 
-        # following are just regression checks to make sure it still works as expected with incr
-        # max 64 bit signed int
+        # following are just regression checks to make sure it still works as
+        # expected with incr max 64 bit signed int
         self.cache.set("num", 9223372036854775807)
 
         self.cache.incr("num", ignore_key_check=True)
@@ -504,7 +540,7 @@ class DjangoRedisCacheTests(unittest.TestCase):
         res = self.cache.delete_pattern("*foo-a*")
         self.assertFalse(bool(res))
 
-    @patch('django_redis.cache.RedisCache.client')
+    @patch("django_redis.cache.RedisCache.client")
     def test_delete_pattern_with_custom_count(self, client_mock):
         for key in ["foo-aa", "foo-ab", "foo-bb", "foo-bc"]:
             self.cache.set(key, "foo")
@@ -513,7 +549,7 @@ class DjangoRedisCacheTests(unittest.TestCase):
 
         client_mock.delete_pattern.assert_called_once_with("*foo-a*", itersize=2)
 
-    @patch('django_redis.cache.RedisCache.client')
+    @patch("django_redis.cache.RedisCache.client")
     def test_delete_pattern_with_settings_default_scan_count(self, client_mock):
         for key in ["foo-aa", "foo-ab", "foo-bb", "foo-bc"]:
             self.cache.set(key, "foo")
@@ -521,7 +557,9 @@ class DjangoRedisCacheTests(unittest.TestCase):
 
         self.cache.delete_pattern("*foo-a*")
 
-        client_mock.delete_pattern.assert_called_once_with("*foo-a*", itersize=expected_count)
+        client_mock.delete_pattern.assert_called_once_with(
+            "*foo-a*", itersize=expected_count
+        )
 
     def test_close(self):
         cache = caches["default"]
@@ -575,6 +613,19 @@ class DjangoRedisCacheTests(unittest.TestCase):
         lock.release()
         self.assertFalse(self.cache.has_key("foobar"))
 
+    def test_lock_released_by_thread(self):
+        lock = self.cache.lock("foobar", thread_local=False)
+        lock.acquire(blocking=True)
+
+        def release_lock(lock_):
+            lock_.release()
+
+        t = threading.Thread(target=release_lock, args=[lock])
+        t.start()
+        t.join()
+
+        self.assertFalse(self.cache.has_key("foobar"))
+
     def test_iter_keys(self):
         cache = caches["default"]
         if isinstance(cache.client, ShardClient):
@@ -631,23 +682,39 @@ class DjangoRedisCacheTests(unittest.TestCase):
         self.assertIsNone(res)
 
     def test_touch_missed_key(self):
-        self.assertIs(self.cache.touch("test_key", -1), False)
+        self.assertIs(self.cache.touch("test_key_does_not_exist", 1), False)
+
+    def test_touch_forever(self):
+        self.cache.set("test_key", "foo", timeout=1)
+        result = self.cache.touch("test_key", None)
+        self.assertIs(result, True)
+        self.assertIsNone(self.cache.ttl("test_key"))
+        time.sleep(2)
+        self.assertEqual(self.cache.get("test_key"), "foo")
+
+    def test_touch_forever_nonexistent(self):
+        result = self.cache.touch("test_key_does_not_exist", None)
+        self.assertIs(result, False)
+
+    def test_touch_default_timeout(self):
+        self.cache.set("test_key", "foo", timeout=1)
+        result = self.cache.touch("test_key")
+        self.assertIs(result, True)
+        time.sleep(2)
+        self.assertEqual(self.cache.get("test_key"), "foo")
 
 
 class DjangoOmitExceptionsTests(unittest.TestCase):
     def setUp(self):
-        self._orig_setting = django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS
-        django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS = True
         caches_setting = copy.deepcopy(settings.CACHES)
         caches_setting["doesnotexist"]["OPTIONS"]["IGNORE_EXCEPTIONS"] = True
-        cm = override_settings(CACHES=caches_setting)
+        cm = override_settings(
+            CACHES=caches_setting, DJANGO_REDIS_IGNORE_EXCEPTIONS=True
+        )
         cm.enable()
         self.addCleanup(cm.disable)
         self.cache = caches["doesnotexist"]
 
-    def tearDown(self):
-        django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS = self._orig_setting
-
     def test_get_many_returns_default_arg(self):
         self.assertIs(self.cache._ignore_exceptions, True)
         self.assertEqual(self.cache.get_many(["key1", "key2", "key3"]), {})
@@ -661,18 +728,15 @@ class DjangoOmitExceptionsTests(unittest.TestCase):
 
 class DjangoOmitExceptionsPriority1Tests(unittest.TestCase):
     def setUp(self):
-        self._orig_setting = django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS
-        django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS = False
         caches_setting = copy.deepcopy(settings.CACHES)
         caches_setting["doesnotexist"]["OPTIONS"]["IGNORE_EXCEPTIONS"] = True
-        cm = override_settings(CACHES=caches_setting)
+        cm = override_settings(
+            CACHES=caches_setting, DJANGO_REDIS_IGNORE_EXCEPTIONS=False
+        )
         cm.enable()
         self.addCleanup(cm.disable)
         self.cache = caches["doesnotexist"]
 
-    def tearDown(self):
-        django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS = self._orig_setting
-
     def test_get(self):
         self.assertIs(self.cache._ignore_exceptions, True)
         self.assertIsNone(self.cache.get("key"))
@@ -680,18 +744,15 @@ class DjangoOmitExceptionsPriority1Tests(unittest.TestCase):
 
 class DjangoOmitExceptionsPriority2Tests(unittest.TestCase):
     def setUp(self):
-        self._orig_setting = django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS
-        django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS = True
         caches_setting = copy.deepcopy(settings.CACHES)
         caches_setting["doesnotexist"]["OPTIONS"]["IGNORE_EXCEPTIONS"] = False
-        cm = override_settings(CACHES=caches_setting)
+        cm = override_settings(
+            CACHES=caches_setting, DJANGO_REDIS_IGNORE_EXCEPTIONS=True
+        )
         cm.enable()
         self.addCleanup(cm.disable)
         self.cache = caches["doesnotexist"]
 
-    def tearDown(self):
-        django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS = self._orig_setting
-
     def test_get(self):
         self.assertIs(self.cache._ignore_exceptions, False)
         with self.assertRaises(ConnectionError):
@@ -721,63 +782,66 @@ class SessionTestsMixin:
         self.assertIs(self.session.accessed, False)
 
     def test_get_empty(self):
-        self.assertIsNone(self.session.get('cat'))
+        self.assertIsNone(self.session.get("cat"))
 
     def test_store(self):
-        self.session['cat'] = "dog"
+        self.session["cat"] = "dog"
         self.assertIs(self.session.modified, True)
-        self.assertEqual(self.session.pop('cat'), 'dog')
+        self.assertEqual(self.session.pop("cat"), "dog")
 
     def test_pop(self):
-        self.session['some key'] = 'exists'
+        self.session["some key"] = "exists"
         # Need to reset these to pretend we haven't accessed it:
         self.accessed = False
         self.modified = False
 
-        self.assertEqual(self.session.pop('some key'), 'exists')
+        self.assertEqual(self.session.pop("some key"), "exists")
         self.assertIs(self.session.accessed, True)
         self.assertIs(self.session.modified, True)
-        self.assertIsNone(self.session.get('some key'))
+        self.assertIsNone(self.session.get("some key"))
 
     def test_pop_default(self):
-        self.assertEqual(self.session.pop('some key', 'does not exist'),
-                         'does not exist')
+        self.assertEqual(
+            self.session.pop("some key", "does not exist"), "does not exist"
+        )
         self.assertIs(self.session.accessed, True)
         self.assertIs(self.session.modified, False)
 
     def test_pop_default_named_argument(self):
-        self.assertEqual(self.session.pop('some key', default='does not exist'), 'does not exist')
+        self.assertEqual(
+            self.session.pop("some key", default="does not exist"), "does not exist"
+        )
         self.assertIs(self.session.accessed, True)
         self.assertIs(self.session.modified, False)
 
     def test_pop_no_default_keyerror_raised(self):
         with self.assertRaises(KeyError):
-            self.session.pop('some key')
+            self.session.pop("some key")
 
     def test_setdefault(self):
-        self.assertEqual(self.session.setdefault('foo', 'bar'), 'bar')
-        self.assertEqual(self.session.setdefault('foo', 'baz'), 'bar')
+        self.assertEqual(self.session.setdefault("foo", "bar"), "bar")
+        self.assertEqual(self.session.setdefault("foo", "baz"), "bar")
         self.assertIs(self.session.accessed, True)
         self.assertIs(self.session.modified, True)
 
     def test_update(self):
-        self.session.update({'update key': 1})
+        self.session.update({"update key": 1})
         self.assertIs(self.session.accessed, True)
         self.assertIs(self.session.modified, True)
-        self.assertEqual(self.session.get('update key'), 1)
+        self.assertEqual(self.session.get("update key"), 1)
 
     def test_has_key(self):
-        self.session['some key'] = 1
+        self.session["some key"] = 1
         self.session.modified = False
         self.session.accessed = False
-        self.assertIn('some key', self.session)
+        self.assertIn("some key", self.session)
         self.assertIs(self.session.accessed, True)
         self.assertIs(self.session.modified, False)
 
     def test_values(self):
         self.assertEqual(list(self.session.values()), [])
         self.assertIs(self.session.accessed, True)
-        self.session['some key'] = 1
+        self.session["some key"] = 1
         self.session.modified = False
         self.session.accessed = False
         self.assertEqual(list(self.session.values()), [1])
@@ -785,26 +849,26 @@ class SessionTestsMixin:
         self.assertIs(self.session.modified, False)
 
     def test_keys(self):
-        self.session['x'] = 1
+        self.session["x"] = 1
         self.session.modified = False
         self.session.accessed = False
-        self.assertEqual(list(self.session.keys()), ['x'])
+        self.assertEqual(list(self.session.keys()), ["x"])
         self.assertIs(self.session.accessed, True)
         self.assertIs(self.session.modified, False)
 
     def test_items(self):
-        self.session['x'] = 1
+        self.session["x"] = 1
         self.session.modified = False
         self.session.accessed = False
-        self.assertEqual(list(self.session.items()), [('x', 1)])
+        self.assertEqual(list(self.session.items()), [("x", 1)])
         self.assertIs(self.session.accessed, True)
         self.assertIs(self.session.modified, False)
 
     def test_clear(self):
-        self.session['x'] = 1
+        self.session["x"] = 1
         self.session.modified = False
         self.session.accessed = False
-        self.assertEqual(list(self.session.items()), [('x', 1)])
+        self.assertEqual(list(self.session.items()), [("x", 1)])
         self.session.clear()
         self.assertEqual(list(self.session.items()), [])
         self.assertIs(self.session.accessed, True)
@@ -820,7 +884,7 @@ class SessionTestsMixin:
         self.assertIs(self.session.exists(self.session.session_key), False)
 
     def test_flush(self):
-        self.session['foo'] = 'bar'
+        self.session["foo"] = "bar"
         self.session.save()
         prev_key = self.session.session_key
         self.session.flush()
@@ -831,7 +895,7 @@ class SessionTestsMixin:
         self.assertIs(self.session.accessed, True)
 
     def test_cycle(self):
-        self.session['a'], self.session['b'] = 'c', 'd'
+        self.session["a"], self.session["b"] = "c", "d"
         self.session.save()
         prev_key = self.session.session_key
         prev_data = list(self.session.items())
@@ -841,51 +905,52 @@ class SessionTestsMixin:
         self.assertEqual(list(self.session.items()), prev_data)
 
     def test_cycle_with_no_session_cache(self):
-        self.session['a'], self.session['b'] = 'c', 'd'
+        self.session["a"], self.session["b"] = "c", "d"
         self.session.save()
         prev_data = self.session.items()
         self.session = self.backend(self.session.session_key)
-        self.assertIs(hasattr(self.session, '_session_cache'), False)
+        self.assertIs(hasattr(self.session, "_session_cache"), False)
         self.session.cycle_key()
         self.assertCountEqual(self.session.items(), prev_data)
 
     def test_save_doesnt_clear_data(self):
-        self.session['a'] = 'b'
+        self.session["a"] = "b"
         self.session.save()
-        self.assertEqual(self.session['a'], 'b')
+        self.assertEqual(self.session["a"], "b")
 
     def test_invalid_key(self):
         # Submitting an invalid session key (either by guessing, or if the db has
         # removed the key) results in a new key being generated.
         try:
-            session = self.backend('1')
+            session = self.backend("1")
             session.save()
-            self.assertNotEqual(session.session_key, '1')
-            self.assertIsNone(session.get('cat'))
+            self.assertNotEqual(session.session_key, "1")
+            self.assertIsNone(session.get("cat"))
             session.delete()
         finally:
             # Some backends leave a stale cache entry for the invalid
             # session key; make sure that entry is manually deleted
-            session.delete('1')
+            session.delete("1")
 
     def test_session_key_empty_string_invalid(self):
         """Falsey values (Such as an empty string) are rejected."""
-        self.session._session_key = ''
+        self.session._session_key = ""
         self.assertIsNone(self.session.session_key)
 
     def test_session_key_too_short_invalid(self):
         """Strings shorter than 8 characters are rejected."""
-        self.session._session_key = '1234567'
+        self.session._session_key = "1234567"
         self.assertIsNone(self.session.session_key)
 
     def test_session_key_valid_string_saved(self):
         """Strings of length 8 and up are accepted and stored."""
-        self.session._session_key = '12345678'
-        self.assertEqual(self.session.session_key, '12345678')
+        self.session._session_key = "12345678"
+        self.assertEqual(self.session.session_key, "12345678")
 
     def test_session_key_is_read_only(self):
         def set_session_key(session):
             session.session_key = session._get_new_session_key()
+
         with self.assertRaises(AttributeError):
             set_session_key(self.session)
 
@@ -969,52 +1034,53 @@ class SessionTestsMixin:
 
     def test_decode(self):
         # Ensure we can decode what we encode
-        data = {'a test key': 'a test value'}
+        data = {"a test key": "a test value"}
         encoded = self.session.encode(data)
         self.assertEqual(self.session.decode(encoded), data)
 
     def test_decode_failure_logged_to_security(self):
-        bad_encode = base64.b64encode(b'flaskdj:alkdjf').decode('ascii')
-        with self.assertLogs('django.security.SuspiciousSession', 'WARNING') as cm:
+        bad_encode = base64.b64encode(b"flaskdj:alkdjf").decode("ascii")
+        with self.assertLogs("django.security.SuspiciousSession", "WARNING") as cm:
             self.assertEqual({}, self.session.decode(bad_encode))
         # The failed decode is logged.
-        self.assertIn('corrupted', cm.output[0])
+        self.assertIn("corrupted", cm.output[0])
 
     def test_actual_expiry(self):
         # this doesn't work with JSONSerializer (serializing timedelta)
-        with override_settings(SESSION_SERIALIZER='django.contrib.sessions.serializers.PickleSerializer'):
+        with override_settings(
+            SESSION_SERIALIZER="django.contrib.sessions.serializers.PickleSerializer"
+        ):
             self.session = self.backend()  # reinitialize after overriding settings
 
             # Regression test for #19200
             old_session_key = None
             new_session_key = None
             try:
-                self.session['foo'] = 'bar'
+                self.session["foo"] = "bar"
                 self.session.set_expiry(-timedelta(seconds=10))
                 self.session.save()
                 old_session_key = self.session.session_key
                 # With an expiry date in the past, the session expires instantly.
                 new_session = self.backend(self.session.session_key)
                 new_session_key = new_session.session_key
-                self.assertNotIn('foo', new_session)
+                self.assertNotIn("foo", new_session)
             finally:
                 self.session.delete(old_session_key)
                 self.session.delete(new_session_key)
 
-    @unittest.skipIf(VERSION < (2, 0), 'Requires Django 2.0+')
     def test_session_load_does_not_create_record(self):
         """
         Loading an unknown session key does not create a session record.
 
         Creating session records on load is a DOS vulnerability.
         """
-        session = self.backend('someunknownkey')
+        session = self.backend("someunknownkey")
         session.load()
 
         self.assertIsNone(session.session_key)
         self.assertIs(session.exists(session.session_key), False)
         # provided unknown key was cycled, not reused
-        self.assertNotEqual(session.session_key, 'someunknownkey')
+        self.assertNotEqual(session.session_key, "someunknownkey")
 
     def test_session_save_does_not_resurrect_session_logged_out_in_other_context(self):
         """
@@ -1024,7 +1090,7 @@ class SessionTestsMixin:
 
         # Create new session.
         s1 = self.backend()
-        s1['test_data'] = 'value1'
+        s1["test_data"] = "value1"
         s1.save(must_create=True)
 
         # Logout in another context.
@@ -1032,7 +1098,7 @@ class SessionTestsMixin:
         s2.delete()
 
         # Modify session in first context.
-        s1['test_data'] = 'value2'
+        s1["test_data"] = "value2"
         with self.assertRaises(UpdateError):
             # This should throw an exception as the session is deleted, not
             # resurrect the session.
@@ -1045,99 +1111,112 @@ class SessionTests(SessionTestsMixin, unittest.TestCase):
     backend = CacheSession
 
     def test_actual_expiry(self):
-        if isinstance(caches[DEFAULT_CACHE_ALIAS].client._serializer, MSGPackSerializer):
+        if isinstance(
+            caches[DEFAULT_CACHE_ALIAS].client._serializer, MSGPackSerializer
+        ):
             self.skipTest("msgpack serializer doesn't support datetime serialization")
         super().test_actual_expiry()
 
 
 class TestDefaultClient(unittest.TestCase):
-    @patch('test_backend.DefaultClient.get_client')
-    @patch('test_backend.DefaultClient.__init__', return_value=None)
-    def test_delete_pattern_calls_get_client_given_no_client(self, init_mock, get_client_mock):
+    @patch("test_backend.DefaultClient.get_client")
+    @patch("test_backend.DefaultClient.__init__", return_value=None)
+    def test_delete_pattern_calls_get_client_given_no_client(
+        self, init_mock, get_client_mock
+    ):
         client = DefaultClient()
         client._backend = Mock()
-        client._backend.key_prefix = ''
+        client._backend.key_prefix = ""
 
-        client.delete_pattern(pattern='foo*')
+        client.delete_pattern(pattern="foo*")
         get_client_mock.assert_called_once_with(write=True)
 
-    @patch('test_backend.DefaultClient.make_pattern')
-    @patch('test_backend.DefaultClient.get_client', return_value=Mock())
-    @patch('test_backend.DefaultClient.__init__', return_value=None)
+    @patch("test_backend.DefaultClient.make_pattern")
+    @patch("test_backend.DefaultClient.get_client", return_value=Mock())
+    @patch("test_backend.DefaultClient.__init__", return_value=None)
     def test_delete_pattern_calls_make_pattern(
-            self, init_mock, get_client_mock, make_pattern_mock):
+        self, init_mock, get_client_mock, make_pattern_mock
+    ):
         client = DefaultClient()
         client._backend = Mock()
-        client._backend.key_prefix = ''
+        client._backend.key_prefix = ""
         get_client_mock.return_value.scan_iter.return_value = []
 
-        client.delete_pattern(pattern='foo*')
+        client.delete_pattern(pattern="foo*")
 
-        kwargs = {'version': None, 'prefix': None}
+        kwargs = {"version": None, "prefix": None}
         # if not isinstance(caches['default'].client, ShardClient):
         # kwargs['prefix'] = None
 
-        make_pattern_mock.assert_called_once_with('foo*', **kwargs)
+        make_pattern_mock.assert_called_once_with("foo*", **kwargs)
 
-    @patch('test_backend.DefaultClient.make_pattern')
-    @patch('test_backend.DefaultClient.get_client', return_value=Mock())
-    @patch('test_backend.DefaultClient.__init__', return_value=None)
+    @patch("test_backend.DefaultClient.make_pattern")
+    @patch("test_backend.DefaultClient.get_client", return_value=Mock())
+    @patch("test_backend.DefaultClient.__init__", return_value=None)
     def test_delete_pattern_calls_scan_iter_with_count_if_itersize_given(
-            self, init_mock, get_client_mock, make_pattern_mock):
+        self, init_mock, get_client_mock, make_pattern_mock
+    ):
         client = DefaultClient()
         client._backend = Mock()
-        client._backend.key_prefix = ''
+        client._backend.key_prefix = ""
         get_client_mock.return_value.scan_iter.return_value = []
 
-        client.delete_pattern(pattern='foo*', itersize=90210)
+        client.delete_pattern(pattern="foo*", itersize=90210)
 
         get_client_mock.return_value.scan_iter.assert_called_once_with(
-            count=90210, match=make_pattern_mock.return_value)
+            count=90210, match=make_pattern_mock.return_value
+        )
 
 
 class TestShardClient(unittest.TestCase):
-
-    @patch('test_backend.DefaultClient.make_pattern')
-    @patch('test_backend.ShardClient.__init__', return_value=None)
+    @patch("test_backend.DefaultClient.make_pattern")
+    @patch("test_backend.ShardClient.__init__", return_value=None)
     def test_delete_pattern_calls_scan_iter_with_count_if_itersize_given(
-            self, init_mock, make_pattern_mock):
+        self, init_mock, make_pattern_mock
+    ):
         client = ShardClient()
         client._backend = Mock()
-        client._backend.key_prefix = ''
+        client._backend.key_prefix = ""
 
         connection = Mock()
         connection.scan_iter.return_value = []
-        client._serverdict = {'test': connection}
+        client._serverdict = {"test": connection}
 
-        client.delete_pattern(pattern='foo*', itersize=10)
+        client.delete_pattern(pattern="foo*", itersize=10)
 
-        connection.scan_iter.assert_called_once_with(count=10, match=make_pattern_mock.return_value)
+        connection.scan_iter.assert_called_once_with(
+            count=10, match=make_pattern_mock.return_value
+        )
 
-    @patch('test_backend.DefaultClient.make_pattern')
-    @patch('test_backend.ShardClient.__init__', return_value=None)
+    @patch("test_backend.DefaultClient.make_pattern")
+    @patch("test_backend.ShardClient.__init__", return_value=None)
     def test_delete_pattern_calls_scan_iter(self, init_mock, make_pattern_mock):
         client = ShardClient()
         client._backend = Mock()
-        client._backend.key_prefix = ''
+        client._backend.key_prefix = ""
         connection = Mock()
         connection.scan_iter.return_value = []
-        client._serverdict = {'test': connection}
+        client._serverdict = {"test": connection}
 
-        client.delete_pattern(pattern='foo*')
+        client.delete_pattern(pattern="foo*")
 
-        connection.scan_iter.assert_called_once_with(match=make_pattern_mock.return_value)
+        connection.scan_iter.assert_called_once_with(
+            match=make_pattern_mock.return_value
+        )
 
-    @patch('test_backend.DefaultClient.make_pattern')
-    @patch('test_backend.ShardClient.__init__', return_value=None)
-    def test_delete_pattern_calls_delete_for_given_keys(self, init_mock, make_pattern_mock):
+    @patch("test_backend.DefaultClient.make_pattern")
+    @patch("test_backend.ShardClient.__init__", return_value=None)
+    def test_delete_pattern_calls_delete_for_given_keys(
+        self, init_mock, make_pattern_mock
+    ):
         client = ShardClient()
         client._backend = Mock()
-        client._backend.key_prefix = ''
+        client._backend.key_prefix = ""
         connection = Mock()
         connection.scan_iter.return_value = [Mock(), Mock()]
         connection.delete.return_value = 0
-        client._serverdict = {'test': connection}
+        client._serverdict = {"test": connection}
 
-        client.delete_pattern(pattern='foo*')
+        client.delete_pattern(pattern="foo*")
 
         connection.delete.assert_called_once_with(*connection.scan_iter.return_value)
