@@ -3,14 +3,11 @@ SECRET_KEY = "django_tests_secret_key"
 CACHES = {
     "default": {
         "BACKEND": "django_redis.cache.RedisCache",
-        "LOCATION": [
-            "redis://127.0.0.1:6379?db=1",
-            "redis://127.0.0.1:6379?db=1",
-        ],
+        "LOCATION": ["redis://127.0.0.1:6379?db=1", "redis://127.0.0.1:6379?db=1"],
         "OPTIONS": {
             "CLIENT_CLASS": "django_redis.client.DefaultClient",
-            "COMPRESSOR": "django_redis.compressors.zlib.ZlibCompressor"
-        }
+            "COMPRESSOR": "django_redis.compressors.zlib.ZlibCompressor",
+        },
     },
     "doesnotexist": {
         "BACKEND": "django_redis.cache.RedisCache",
@@ -18,7 +15,7 @@ CACHES = {
         "OPTIONS": {
             "CLIENT_CLASS": "django_redis.client.DefaultClient",
             "COMPRESSOR": "django_redis.compressors.zlib.ZlibCompressor",
-        }
+        },
     },
     "sample": {
         "BACKEND": "django_redis.cache.RedisCache",
@@ -26,7 +23,7 @@ CACHES = {
         "OPTIONS": {
             "CLIENT_CLASS": "django_redis.client.DefaultClient",
             "COMPRESSOR": "django_redis.compressors.zlib.ZlibCompressor",
-        }
+        },
     },
     "with_prefix": {
         "BACKEND": "django_redis.cache.RedisCache",
@@ -39,6 +36,4 @@ CACHES = {
     },
 }
 
-INSTALLED_APPS = (
-    "django.contrib.sessions",
-)
+INSTALLED_APPS = ["django.contrib.sessions"]
